@@ -1,25 +1,22 @@
 /****************************************************************************
 
- Copyright (C) 2002-2007 Gilles Debunne (Gilles.Debunne@imag.fr)
+ Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library.
- Version 2.2.6-3, released on August 28, 2007.
+ This file is part of the QGLViewer library version 2.3.1.
 
- http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer
+ http://www.libqglviewer.com - contact@libqglviewer.com
 
- libQGLViewer is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ This file may be used under the terms of the GNU General Public License 
+ versions 2.0 or 3.0 as published by the Free Software Foundation and
+ appearing in the LICENSE file included in the packaging of this file.
+ In addition, as a special exception, Gilles Debunne gives you certain 
+ additional rights, described in the file GPL_EXCEPTION in this package.
 
- libQGLViewer is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+ libQGLViewer uses dual licensing. Commercial/proprietary software must
+ purchase a libQGLViewer Commercial License.
 
- You should have received a copy of the GNU General Public License
- along with libQGLViewer; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
 
@@ -279,8 +276,8 @@ void Quaternion::initFromDOMElement(const QDomElement& element)
   *this = q;
 }
 
-/*! Constructs a Quaternion from a \c QDomElement representing an XML code of the form \c
-  <anyTagName q0=".." q1=".." q2=".." q3=".." />.
+/*! Constructs a Quaternion from a \c QDomElement representing an XML code of the form
+  \code< anyTagName q0=".." q1=".." q2=".." q3=".." />\endcode
 
   If one of these attributes is missing or is not a number, a warning is displayed and the associated
   value is respectively set to 0, 0, 0 and 1 (identity Quaternion).
