@@ -1,25 +1,22 @@
 /****************************************************************************
 
- Copyright (C) 2002-2007 Gilles Debunne (Gilles.Debunne@imag.fr)
+ Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library.
- Version 2.2.6-3, released on August 28, 2007.
+ This file is part of the QGLViewer library version 2.3.1.
 
- http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer
+ http://www.libqglviewer.com - contact@libqglviewer.com
 
- libQGLViewer is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ This file may be used under the terms of the GNU General Public License 
+ versions 2.0 or 3.0 as published by the Free Software Foundation and
+ appearing in the LICENSE file included in the packaging of this file.
+ In addition, as a special exception, Gilles Debunne gives you certain 
+ additional rights, described in the file GPL_EXCEPTION in this package.
 
- libQGLViewer is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+ libQGLViewer uses dual licensing. Commercial/proprietary software must
+ purchase a libQGLViewer Commercial License.
 
- You should have received a copy of the GNU General Public License
- along with libQGLViewer; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
 
@@ -31,11 +28,7 @@
 # else
 #  include <qcheckbox.h>
 #  include <qcombobox.h>
-#  if QT_VERSION >= 0x030000
-#   include "VRenderInterface.Qt3.h"
-#  else
-#   include "VRenderInterface.Qt2.h"
-#  endif
+#  include "VRenderInterface.Qt3.h"
 # endif
 # include "VRender/VRender.h"
 #endif
@@ -45,11 +38,7 @@
 #else
 # include <qspinbox.h>
 # include <qcheckbox.h>
-# if QT_VERSION >= 0x030000
-#  include "ImageInterface.Qt3.h"
-# else
-#  include "ImageInterface.Qt2.h"
-# endif
+# include "ImageInterface.Qt3.h"
 #endif
 
 // Output format list
@@ -257,7 +246,7 @@ class ProgressDialog
 {
 public:
   static void showProgressDialog(QGLWidget* parent);
-  static void updateProgress(float progress, const std::string& stepString);
+  static void updateProgress(float progress, const QString& stepString);
   static void hideProgressDialog();
 
 private:
@@ -279,14 +268,14 @@ void ProgressDialog::showProgressDialog(QGLWidget* parent)
   progressDialog->show();
 }
 
-void ProgressDialog::updateProgress(float progress, const std::string& stepString)
+void ProgressDialog::updateProgress(float progress, const QString& stepString)
 {
 #if QT_VERSION >= 0x040000
   progressDialog->setValue(int(progress*100));
 #else
   progressDialog->setProgress(int(progress*100));
 #endif
-  QString message(stepString.c_str());
+  QString message(stepString);
   if (message.length() > 33)
     message = message.left(17) + "..." + message.right(12);
   progressDialog->setLabelText(message);
@@ -340,11 +329,7 @@ static int saveVectorialSnapshot(const QString& fileName, QGLWidget* widget, con
     return -1;
 
   vrender::VRenderParams vparams;
-#if QT_VERSION >= 0x040000
-  vparams.setFilename(fileName.toLatin1().constData());
-#else
   vparams.setFilename(fileName);
-#endif
 
   if (snapshotFormat == "EPS")	vparams.setFormat(vrender::VRenderParams::EPS);
   if (snapshotFormat == "PS")	vparams.setFormat(vrender::VRenderParams::PS);
