@@ -1,25 +1,22 @@
 /****************************************************************************
 
- Copyright (C) 2002-2007 Gilles Debunne (Gilles.Debunne@imag.fr)
+ Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library.
- Version 2.2.6-3, released on August 28, 2007.
+ This file is part of the QGLViewer library version 2.3.1.
 
- http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer
+ http://www.libqglviewer.com - contact@libqglviewer.com
 
- libQGLViewer is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ This file may be used under the terms of the GNU General Public License 
+ versions 2.0 or 3.0 as published by the Free Software Foundation and
+ appearing in the LICENSE file included in the packaging of this file.
+ In addition, as a special exception, Gilles Debunne gives you certain 
+ additional rights, described in the file GPL_EXCEPTION in this package.
 
- libQGLViewer is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+ libQGLViewer uses dual licensing. Commercial/proprietary software must
+ purchase a libQGLViewer Commercial License.
 
- You should have received a copy of the GNU General Public License
- along with libQGLViewer; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
 
@@ -260,15 +257,6 @@ namespace
 		      GL_RGBA, GL_UNSIGNED_BYTE, glImg.bits());
     return to;
   }
-  // This function is dummy. See trick in .h
-  void forceInstanciation()
-  {
-    Drawer d;
-    const Board::ConstStackHandle* s = NULL;
-    d.drawTransparentPieces((*s)->begin(),(*s)->end(),(*s).stackCoord());
-    Board::Ghost* g = NULL;
-    d.drawTransparentPieces(g->stack.begin(),g->stack.end(),g->coord);
-  }
 }
 //************************************************************
 // Implementation of Drawer
@@ -424,9 +412,8 @@ Drawer::drawTransparentPiece(Color col,
   glPopMatrix();
   endTexture();
 }
-template <class O>
 void
-Drawer::drawTransparentPieces(O first,O last,const Board::Coord& c,float h,float a) const
+Drawer::drawTransparentPieces(Stack::const_iterator first,Stack::const_iterator last,const Board::Coord& c,float h,float a) const
 {
   startTexture();
   glPushMatrix();
@@ -707,5 +694,5 @@ Drawer::boardRadius() const
 Vec
 Drawer::defaultEyePosition() const
 {
-  return boardCenter()+boardRadius()*Vec(0.0, -1.7, 1.0);
+  return boardCenter()+boardRadius()*Vec(0.0, -1.7f, 1.0);
 }
