@@ -1,25 +1,22 @@
 /****************************************************************************
 
- Copyright (C) 2002-2007 Gilles Debunne (Gilles.Debunne@imag.fr)
+ Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library.
- Version 2.2.6-3, released on August 28, 2007.
+ This file is part of the QGLViewer library version 2.3.1.
 
- http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer
+ http://www.libqglviewer.com - contact@libqglviewer.com
 
- libQGLViewer is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ This file may be used under the terms of the GNU General Public License 
+ versions 2.0 or 3.0 as published by the Free Software Foundation and
+ appearing in the LICENSE file included in the packaging of this file.
+ In addition, as a special exception, Gilles Debunne gives you certain 
+ additional rights, described in the file GPL_EXCEPTION in this package.
 
- libQGLViewer is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+ libQGLViewer uses dual licensing. Commercial/proprietary software must
+ purchase a libQGLViewer Commercial License.
 
- You should have received a copy of the GNU General Public License
- along with libQGLViewer; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
 
@@ -30,6 +27,10 @@
 #include <math.h>
 #include <qmessagebox.h>
 
+#if QT_VERSION >= 0x040000
+# include <QMouseEvent>
+#endif
+
 using namespace std;
 using namespace qglviewer;
 using namespace dvonn;
@@ -300,9 +301,9 @@ DvonnViewer::initSpotLight()
 
   glLightf( GL_LIGHT1, GL_SPOT_EXPONENT,  2.0);
   glLightf( GL_LIGHT1, GL_SPOT_CUTOFF,    60.0);
-  glLightf( GL_LIGHT1, GL_CONSTANT_ATTENUATION, 0.1);
-  glLightf( GL_LIGHT1, GL_LINEAR_ATTENUATION, 0.3);
-  glLightf( GL_LIGHT1, GL_QUADRATIC_ATTENUATION, 0.3);
+  glLightf( GL_LIGHT1, GL_CONSTANT_ATTENUATION, 0.1f);
+  glLightf( GL_LIGHT1, GL_LINEAR_ATTENUATION, 0.3f);
+  glLightf( GL_LIGHT1, GL_QUADRATIC_ATTENUATION, 0.3f);
   glLightfv(GL_LIGHT1, GL_AMBIENT,  light_ambient);
   glLightfv(GL_LIGHT1, GL_SPECULAR, light_specular);
   glLightfv(GL_LIGHT1, GL_DIFFUSE,  light_diffuse);
