@@ -1,31 +1,27 @@
 /****************************************************************************
 
- Copyright (C) 2002-2007 Gilles Debunne (Gilles.Debunne@imag.fr)
+ Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library.
- Version 2.2.6-3, released on August 28, 2007.
+ This file is part of the QGLViewer library version 2.3.1.
 
- http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer
+ http://www.libqglviewer.com - contact@libqglviewer.com
 
- libQGLViewer is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ This file may be used under the terms of the GNU General Public License 
+ versions 2.0 or 3.0 as published by the Free Software Foundation and
+ appearing in the LICENSE file included in the packaging of this file.
+ In addition, as a special exception, Gilles Debunne gives you certain 
+ additional rights, described in the file GPL_EXCEPTION in this package.
 
- libQGLViewer is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+ libQGLViewer uses dual licensing. Commercial/proprietary software must
+ purchase a libQGLViewer Commercial License.
 
- You should have received a copy of the GNU General Public License
- along with libQGLViewer; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
 
 // TP OpenGL: Joerg Liebelt, Serigne Sow
 #include <stdio.h>
-
 #include "quadtree.h"
 
 #define SQR( number )		( number*number )
@@ -206,37 +202,30 @@ void QUADTREE::PropagateRoughness( void )
 	  for( x=edgeOffset; x<sizeHeightMap-edgeOffset; x+=( edgeLength ) )
 	    {
 	      //haut, milieu
-	      localD2= ( int )ceil( abs( ( ( GetTrueHeightAtPoint( x-edgeOffset, z+edgeOffset )+
-					     GetTrueHeightAtPoint( x+edgeOffset, z+edgeOffset ) )>>1 )-
-					 GetTrueHeightAtPoint( x, z+edgeOffset ) ) );
+	      localD2= (int) ceil( (int)( abs( ( ( GetTrueHeightAtPoint( x-edgeOffset, z+edgeOffset )+GetTrueHeightAtPoint( x+edgeOffset, z+edgeOffset ) )>>1 ) - GetTrueHeightAtPoint( x, z+edgeOffset ) ) ) );
 	      //a droite, milieu
 	      dH= ( int )ceil( abs( ( ( GetTrueHeightAtPoint( x+edgeOffset, z+edgeOffset )+
-					GetTrueHeightAtPoint( x+edgeOffset, z-edgeOffset ) )>>1 )-
-				    GetTrueHeightAtPoint( x+edgeOffset, z ) ) );
+					GetTrueHeightAtPoint( x+edgeOffset, z-edgeOffset ) )>>1 ) - GetTrueHeightAtPoint( x+edgeOffset, z ) ) );
 	      localD2= MAX( localD2, dH );
 
 	      //en bas, milieu
 	      dH= ( int )ceil( abs( ( ( GetTrueHeightAtPoint( x-edgeOffset, z-edgeOffset )+
-					GetTrueHeightAtPoint( x+edgeOffset, z-edgeOffset ) )>>1 )-
-				    GetTrueHeightAtPoint( x, z-edgeOffset ) ) );
+					GetTrueHeightAtPoint( x+edgeOffset, z-edgeOffset ) )>>1 ) - GetTrueHeightAtPoint( x, z-edgeOffset ) ) );
 	      localD2= MAX( localD2, dH );
 
 	      //a gauche, milieu
 	      dH= ( int )ceil( abs( ( ( GetTrueHeightAtPoint( x-edgeOffset, z+edgeOffset )+
-					GetTrueHeightAtPoint( x-edgeOffset, z-edgeOffset ) )>>1 )-
-				    GetTrueHeightAtPoint( x-edgeOffset, z ) ) );
+					GetTrueHeightAtPoint( x-edgeOffset, z-edgeOffset ) )>>1 ) - GetTrueHeightAtPoint( x-edgeOffset, z ) ) );
 	      localD2= MAX( localD2, dH );
 
 	      //deux points sur la diagonale de bas gauche a haut droite
 	      dH= ( int )ceil( abs( ( ( GetTrueHeightAtPoint( x-edgeOffset, z-edgeOffset )+
-					GetTrueHeightAtPoint( x+edgeOffset, z+edgeOffset ) )>>1 )-
-				    GetTrueHeightAtPoint( x, z ) ) );
+					GetTrueHeightAtPoint( x+edgeOffset, z+edgeOffset ) )>>1 ) - GetTrueHeightAtPoint( x, z ) ) );
 	      localD2= MAX( localD2, dH );
 
 	      //deux points sur la diagonale de bas droite a haut gauche
 	      dH= ( int )ceil( abs( ( ( GetTrueHeightAtPoint( x+edgeOffset, z-edgeOffset )+
-					GetTrueHeightAtPoint( x-edgeOffset, z+edgeOffset ) )>>1 )-
-				    GetTrueHeightAtPoint( x, z ) ) );
+					GetTrueHeightAtPoint( x-edgeOffset, z+edgeOffset ) )>>1 ) - GetTrueHeightAtPoint( x, z ) ) );
 	      localD2= MAX( localD2, dH );
 	      // localD2 de 0 a 255, normaliser par la taille du bloc actuelle (de 3 a sizeHeightMap)
 	      // ... donc multiplier par 3 pour obtenir une precision maximale de 0 a 255 pour d2
