@@ -1,59 +1,53 @@
 /****************************************************************************
 
- Copyright (C) 2002-2007 Gilles Debunne (Gilles.Debunne@imag.fr)
+ Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library.
- Version 2.2.6-3, released on August 28, 2007.
+ This file is part of the QGLViewer library version 2.3.1.
 
- http://artis.imag.fr/Members/Gilles.Debunne/QGLViewer
+ http://www.libqglviewer.com - contact@libqglviewer.com
 
- libQGLViewer is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+ This file may be used under the terms of the GNU General Public License 
+ versions 2.0 or 3.0 as published by the Free Software Foundation and
+ appearing in the LICENSE file included in the packaging of this file.
+ In addition, as a special exception, Gilles Debunne gives you certain 
+ additional rights, described in the file GPL_EXCEPTION in this package.
 
- libQGLViewer is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+ libQGLViewer uses dual licensing. Commercial/proprietary software must
+ purchase a libQGLViewer Commercial License.
 
- You should have received a copy of the GNU General Public License
- along with libQGLViewer; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
 
 // TP OpenGL: Joerg Liebelt, Serigne Sow
 #include <stdio.h>
 #include <math.h>
+#include <qfile.h>
 #include <time.h>
 #include "terrain.h"
 
 
-bool TERRAIN::LoadHeightMap( char* filename, int size )
+bool TERRAIN::LoadHeightMap(const QString& filename, int size)
 {
-  FILE* pFile;
-
   if( heightMap.arrayHeightMap )
     UnloadHeightMap( );
 
-  pFile= fopen( filename, "rb" );
-  if( pFile==NULL )
-    {
-      return false;
-    }
+  QFile pFile(filename);
+  if (!pFile.open(QIODevice::ReadOnly | QIODevice::Text))
+    return false;
 
   heightMap.arrayHeightMap = new unsigned char [size*size];
 
   if( heightMap.arrayHeightMap==NULL )
-    {
-      return false;
-    }
+    return false;
 
   //lire la carte d'hauteurs, format RAW
-  fread( heightMap.arrayHeightMap, 1, size*size, pFile );
-
-  fclose( pFile );
+  QDataStream in(&pFile);
+  for (int i=0; i<sizeHeightMap*sizeHeightMap; i++)
+    in >> heightMap.arrayHeightMap[i];
+  
+  pFile.close();
 
   sizeHeightMap = size;
 
@@ -61,24 +55,20 @@ bool TERRAIN::LoadHeightMap( char* filename, int size )
 }
 
 
-bool TERRAIN::SaveHeightMap( char* filename )
+bool TERRAIN::SaveHeightMap(const QString& filename )
 {
-  FILE* pFile;
-
-  pFile= fopen( filename, "wb" );
-  if( pFile==NULL )
-    {
-      return false;
-    }
+  QFile pFile(filename);
+  if (!pFile.open(QIODevice::WriteOnly | QIODevice::Text))
+    return false;
 
   if( heightMap.arrayHeightMap==NULL )
-    {
-      return false;
-    }
+    return false;
 
-  fwrite( heightMap.arrayHeightMap, 1, sizeHeightMap*sizeHeightMap, pFile );
+  QDataStream out(&pFile);
+  for (int i=0; i<sizeHeightMap*sizeHeightMap; i++)
+    out << heightMap.arrayHeightMap[i];
 
-  fclose( pFile );
+  pFile.close();
 
   return true;
 }
@@ -581,7 +571,7 @@ void TERRAIN::StepLightingDirection(void)
   else if ((directionX==-1)&&(directionZ==0)) {directionZ--;}
 }
 
-bool TERRAIN::LoadTexture( char* filename )
+bool TERRAIN::LoadTexture( const QString& filename )
 {
   int type;
   if (!myTexture.load(filename))
@@ -605,7 +595,7 @@ bool TERRAIN::LoadTexture( char* filename )
 }
 
 //besoin d'un fonctionnement different car mipmap utilise
-bool TERRAIN::LoadDetailMap( char* filename )
+bool TERRAIN::LoadDetailMap( const QString& filename )
 {
   int type;
   if (!myDetailMap.load(filename))
